hmLoadTopic({
hmKeywords:"Hex Compare,Hex Compare session settings",
hmTitle:"Hex Compare Settings",
hmDescription:"Pick Session > Session Settings to open the Session Settings dialog.",
hmPrevLink:"sessiontablerows.html",
hmNextLink:"sessionhexspecs.html",
hmParentLink:"session_settings.html",
hmBreadCrumbs:"<a href=\"settings_reference.html\">Settings Reference<\/a> &gt; <a href=\"session_settings.html\">Session Settings<\/a>",
hmTitlePath:"Settings Reference > Session Settings > Hex Compare",
hmHeader:"<h1 class=\"p_Heading1\"><span class=\"f_Heading1\">Hex Compare Settings<\/span><\/h1>\n\r",
hmBody:"<p class=\"p_Normal\">Pick <span class=\"f_Command\">Session &gt; Session Settings<\/span> to open the Session Settings dialog.<\/p>\n\r<p class=\"p_Normal\">Click the tab containing the settings you want to edit:<\/p>\n\r<p class=\"p_Normal\"><a href=\"sessionhexspecs.html\" class=\"topiclink\">Specs<\/a><\/p>\n\r<p class=\"p_Normal\"><a href=\"sessionhexformats.html\" class=\"topiclink\">Format<\/a><\/p>\n\r<p class=\"p_Normal\"><a href=\"sessionhexcomparison.html\" class=\"topiclink\">Comparison<\/a><\/p>\n\r"
})
